@@ -29,7 +29,7 @@ import (
 	appsv1 "k8s.io/api/apps/v1"
 	apiv1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	schedulernodeinfo "k8s.io/kubernetes/pkg/scheduler/nodeinfo"
+	schedulerframework "k8s.io/kubernetes/pkg/scheduler/framework/v1alpha1"
 )
 
 func TestGetNodeInfosForGroups(t *testing.T) {
@@ -43,13 +43,13 @@ func TestGetNodeInfosForGroups(t *testing.T) {
 	SetNodeReadyState(unready4, false, time.Now())
 
 	tn := BuildTestNode("tn", 5000, 5000)
-	tni := schedulernodeinfo.NewNodeInfo()
+	tni := schedulerframework.NewNodeInfo()
 	tni.SetNode(tn)
 
 	// Cloud provider with TemplateNodeInfo implemented.
 	provider1 := testprovider.NewTestAutoprovisioningCloudProvider(
 		nil, nil, nil, nil, nil,
-		map[string]*schedulernodeinfo.NodeInfo{"ng3": tni, "ng4": tni})
+		map[string]*schedulerframework.NodeInfo{"ng3": tni, "ng4": tni})
 	provider1.AddNodeGroup("ng1", 1, 10, 1) // Nodegroup with ready node.
 	provider1.AddNode("ng1", ready1)
 	provider1.AddNodeGroup("ng2", 1, 10, 1) // Nodegroup with ready and unready node.
@@ -108,7 +108,7 @@ func TestGetNodeInfosForGroupsCache(t *testing.T) {
 	SetNodeReadyState(ready6, true, time.Now())
 
 	tn := BuildTestNode("tn", 10000, 10000)
-	tni := schedulernodeinfo.NewNodeInfo()
+	tni := schedulerframework.NewNodeInfo()
 	tni.SetNode(tn)
 
 	lastDeletedGroup := ""
@@ -120,7 +120,7 @@ func TestGetNodeInfosForGroupsCache(t *testing.T) {
 	// Cloud provider with TemplateNodeInfo implemented.
 	provider1 := testprovider.NewTestAutoprovisioningCloudProvider(
 		nil, nil, nil, onDeleteGroup, nil,
-		map[string]*schedulernodeinfo.NodeInfo{"ng3": tni, "ng4": tni})
+		map[string]*schedulerframework.NodeInfo{"ng3": tni, "ng4": tni})
 	provider1.AddNodeGroup("ng1", 1, 10, 1) // Nodegroup with ready node.
 	provider1.AddNode("ng1", ready1)
 	provider1.AddNodeGroup("ng2", 1, 10, 1) // Nodegroup with ready and unready node.
@@ -138,7 +138,7 @@ func TestGetNodeInfosForGroupsCache(t *testing.T) {
 	predicateChecker, err := simulator.NewTestPredicateChecker()
 	assert.NoError(t, err)
 
-	nodeInfoCache := make(map[string]*schedulernodeinfo.NodeInfo)
+	nodeInfoCache := make(map[string]*schedulerframework.NodeInfo)
 
 	// Fill cache
 	res, err := GetNodeInfosForGroups([]*apiv1.Node{unready4, unready3, ready2, ready1}, nodeInfoCache,
@@ -196,10 +196,10 @@ func TestGetNodeInfosForGroupsCache(t *testing.T) {
 	assert.False(t, found)
 
 	// Fill cache manually
-	infoNg4Node6 := schedulernodeinfo.NewNodeInfo()
+	infoNg4Node6 := schedulerframework.NewNodeInfo()
 	err2 := infoNg4Node6.SetNode(ready6.DeepCopy())
 	assert.NoError(t, err2)
-	nodeInfoCache = map[string]*schedulernodeinfo.NodeInfo{"ng4": infoNg4Node6}
+	nodeInfoCache = map[string]*schedulerframework.NodeInfo{"ng4": infoNg4Node6}
 	// Check if cache was used
 	res, err = GetNodeInfosForGroups([]*apiv1.Node{ready1, ready2}, nodeInfoCache,
 		provider1, registry, []*appsv1.DaemonSet{}, predicateChecker, nil)
@@ -225,12 +225,12 @@ func TestSanitizeNodeInfo(t *testing.T) {
 
 	node := BuildTestNode("node", 1000, 1000)
 
-	nodeInfo := schedulernodeinfo.NewNodeInfo(pod)
+	nodeInfo := schedulerframework.NewNodeInfo(pod)
 	nodeInfo.SetNode(node)
 
 	res, err := sanitizeNodeInfo(nodeInfo, "test-group", nil)
 	assert.NoError(t, err)
-	assert.Equal(t, 1, len(res.Pods()))
+	assert.Equal(t, 1, len(res.Pods))
 }
 
 func TestSanitizeLabels(t *testing.T) {
