@@ -20,7 +20,7 @@ import (
 	"fmt"
 	"strings"
 
-	"k8s.io/klog"
+	klog "k8s.io/klog/v2"
 
 	apiv1 "k8s.io/api/core/v1"
 
